# Changelog

<!--next-version-placeholder-->

## v0.1.2 (2022-08-11)


## v0.1.1 (2022-07-17)
### Fix
* Requirements crash ([`0854fea`](https://github.com/Mara-Li/mkdocs_custom_fences/commit/0854fea5c0952e855ed971113a567ff99eec3aff))

### Documentation
* Fix typo ([`272fa35`](https://github.com/Mara-Li/mkdocs_custom_fences/commit/272fa35c16f94a2ddce5b1e46f1e848d8db8f75a))
* Adding README ([`c0671d1`](https://github.com/Mara-Li/mkdocs_custom_fences/commit/c0671d12598c212d36eadd02ff38f35c986cd363))
* Adding a list for all custom fences ([`fe05fb7`](https://github.com/Mara-Li/mkdocs_custom_fences/commit/fe05fb72bd84f522998e868c56f9544162aa5f64))

## v0.1.0 (2022-03-29)
### Feature
* Adding md_render ([`8835ded`](https://github.com/Mara-Li/mkdocs_custom_fences/commit/8835ded383e65ab837d254b841b984c571d763ed))

### Fix
* Setup ([`4c84ac7`](https://github.com/Mara-Li/mkdocs_custom_fences/commit/4c84ac7c88ed216deb156a3a671e2b061c88249b))
